bayespy.inference.vmp.nodes.beta.BetaMoments.compute_dims_from_values
=====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaMoments.compute_dims_from_values